//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Device/Unit/AxisNames.h
//! @brief     Defines axisUnitLabel and maps in namespace AxisNames.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_DEVICE_UNIT_AXISNAMES_H
#define BORNAGAIN_DEVICE_UNIT_AXISNAMES_H

#include "Device/Unit/Axes.h"
#include "Wrap/WinDllMacros.h"
#include <map>
#include <string>

const std::map<Axes::Units, const char*> axisUnitLabel = {{Axes::Units::UNDEFINED, "undefined"},
                                                          {Axes::Units::NBINS, "bin"},
                                                          {Axes::Units::RADIANS, "rad"},
                                                          {Axes::Units::DEGREES, "deg"},
                                                          {Axes::Units::MM, "mm"},
                                                          {Axes::Units::QSPACE, "1/nm"},
                                                          {Axes::Units::QXQY, "1/nm"},
                                                          {Axes::Units::RQ4, "nm^-4?"}};

//! Contains const maps that give the right axis names for different detector types and units
//! @ingroup detector

namespace AxisNames {
extern BA_DEVICE_API_ const std::map<Axes::Units, std::string> sphericalAxis0;
extern BA_DEVICE_API_ const std::map<Axes::Units, std::string> sphericalAxis1;
extern BA_DEVICE_API_ const std::map<Axes::Units, std::string> rectangularAxis0;
extern BA_DEVICE_API_ const std::map<Axes::Units, std::string> rectangularAxis1;
extern BA_DEVICE_API_ const std::map<Axes::Units, std::string> offSpecularAxis0;
extern BA_DEVICE_API_ const std::map<Axes::Units, std::string> offSpecularAxis1;
extern BA_DEVICE_API_ const std::map<Axes::Units, std::string> specAxis;
extern BA_DEVICE_API_ const std::map<Axes::Units, std::string> specAxisQ;
extern BA_DEVICE_API_ const std::map<Axes::Units, std::string> sampleDepthAxis;
} // namespace AxisNames

#endif // BORNAGAIN_DEVICE_UNIT_AXISNAMES_H
#endif // USER_API
